# -*- encoding: UTF-8 -*--*-
# This routine is taken from http://extensions.services.openoffice.org/project/DefaultBrowser

import unohelper
from com.sun.star.awt import XContainerWindowEventHandler
from com.sun.star.lang import XServiceInfo


class OptionPageBase(object):
	def __init__(self, ctx, window):
		self.ctx = ctx
		self.window = window
	
	def loadData(self, ev):
		pass
	
	def saveData(self, ev):
		pass


class DialogEventHandlerBase(unohelper.Base, XServiceInfo, XContainerWindowEventHandler):
	""" Dialog handler for option pages. """
	
	# implementation name of the component
	IMPL_NAME = ''
	# supported service names as tuple
	ServiceNames = (IMPL_NAME,)
	
	def __init__(self, ctx):
		self.ctx = ctx
		
		# all pages
		self.pages = {}
		# class for pages key=dlg:id, value: class inherits OptionPageBase
		self.page_classes = {}
	
	# XServiceInfo
	def supportsService(self,name):
		return (name in self.ServiceNames)
	
	def getImplementationName(self):
		return self.IMPL_NAME
	
	def getSupportedServiceNames(self):
		return self.ServiceNames
	
	# XContainerWindowEventHandler
	def getSupportedMethodNames(self):
		return ("external_event",)
	
	def callHandlerMethod(self, window, ev, method):
		"""All events about options window handled by this function."""
		if method == "external_event":
			try:
				self.handleExternalEvent(window, ev)
			except:
				print e
		return True
	
	def handleExternalEvent(self, window, eventName):
		#if dbg: print eventName
		ret = False
		if eventName == 'ok':
			ret = self.saveData(window, eventName)
		elif eventName == 'back' or eventName == 'initialize':
			ret = self.loadData(window, eventName)
		return ret
	
	def loadData(self, window, ev):
		""" load data. """
		name = window.getModel().Name
		try:
			page = self.pages.get(name, None)
			if page is None:
				page_class = self.page_classes.get(name, None)
				if page_class:
					page = page_class(self.ctx, window)
					self.pages[name] = page
		except Exception as e:
			print(e)
		
		if page:
			return page.loadData(ev)
		return False
	
	def saveData(self, window, ev):
		""" save data. """
		name = window.getModel().Name
		
		page = self.pages.get(name, None)
		if page:
			return page.saveData(ev)
		return False


class Handler(DialogEventHandlerBase):
	
	IMPL_NAME = 'vnd.pycalendar.options'
	ServiceNames = (IMPL_NAME,)
	
	""" Dialog event handler for "Calendar for Calc" option page. """
	def __init__(self, ctx):
		DialogEventHandlerBase.__init__(self, ctx)
		
		self.page_classes = {'Dialog': pycalendarpage}


from com.sun.star.awt import XActionListener
from com.sun.star.lang import XEventListener

from com.sun.star.beans import PropertyValue
from com.sun.star.ui.dialogs.TemplateDescription import (
	FILEOPEN_SIMPLE as TD_FILEOPEN_SIMPLE)
from com.sun.star.beans.PropertyState import (
	DIRECT_VALUE as PS_DIRECT_VALUE)


class pycalendarpage (OptionPageBase, XEventListener, unohelper.Base):
	
	ConfigNode = '/vnd.pycalendar.config/settings'
	
	# XEventListener
	def disposing(self, ev): pass
	
	def loadData(self, ev):
		window = self.window
		
		try:
			reader = self.config_reader(self.ConfigNode)
		except Exception as e:
			print(e)
		
		if reader:
			#settings = reader.getPropertyValue('settings')
			if reader.FirstWeekDay == 0:
				window.getControl('FirstWeekDay0').setState(1)
			else:
				window.getControl('FirstWeekDay6').setState(1)
			window.getControl('TextField1').setText(reader.DateFormatKey)
		return True
	
	def saveData(self, ev):
		window = self.window
		
		writer = self.config_writer(self.ConfigNode)
		if writer:
			#settings = writer.getPropertyValue('settings')
			writer.FirstWeekDay = (0 if window.getControl('FirstWeekDay0').getState()==1 else 6)
			writer.DateFormatKey = window.getControl('TextField1').getText()
			writer.commitChanges()
		return True
	
	def config_reader(self, node_name):
		arg = PropertyValue('nodepath', 0, node_name, PS_DIRECT_VALUE)
		cp = self.ctx.getServiceManager().createInstanceWithContext(
			'com.sun.star.configuration.ConfigurationProvider', self.ctx)
		return cp.createInstanceWithArguments(
			'com.sun.star.configuration.ConfigurationAccess', (arg,))
		
	def config_writer(self, node_name):
		arg = PropertyValue('nodepath', 0, node_name, PS_DIRECT_VALUE)
		cp = self.ctx.getServiceManager().createInstanceWithContext(
			'com.sun.star.configuration.ConfigurationProvider', self.ctx)
		return cp.createInstanceWithArguments(
			'com.sun.star.configuration.ConfigurationUpdateAccess', (arg,))


g_ImplementationHelper = unohelper.ImplementationHelper()
g_ImplementationHelper.addImplementation(
	Handler, 'vnd.pycalendar.options', ('vnd.pycalendar.options',))
